summaryrefslogtreecommitdiff
path: root/jstests/multiVersion/targetedTestsLastLtsFeatures
diff options
context:
space:
mode:
authorMihai Andrei <mihai.andrei@10gen.com>2022-05-17 02:12:58 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2022-05-17 02:38:30 +0000
commit7ed364e8922e42822c2d1bc2e41a66159eb7ddcb (patch)
tree02e786c32a59ea572097ab0e9269846dc1d664e1 /jstests/multiVersion/targetedTestsLastLtsFeatures
parent252235fda4d45e85db342bb6437b1587b980b1ed (diff)
downloadmongo-7ed364e8922e42822c2d1bc2e41a66159eb7ddcb.tar.gz
SERVER-66445 Make the classic engine the default execution engine
(cherry picked from commit 40109e237a0ffaf41d26b5465920d12bc6a3f304)
Diffstat (limited to 'jstests/multiVersion/targetedTestsLastLtsFeatures')
-rw-r--r--jstests/multiVersion/targetedTestsLastLtsFeatures/accumulator_fix_last_lts.js13
1 files changed, 8 insertions, 5 deletions
diff --git a/jstests/multiVersion/targetedTestsLastLtsFeatures/accumulator_fix_last_lts.js b/jstests/multiVersion/targetedTestsLastLtsFeatures/accumulator_fix_last_lts.js
index e8d4bf71c14..8e8d6573796 100644
--- a/jstests/multiVersion/targetedTestsLastLtsFeatures/accumulator_fix_last_lts.js
+++ b/jstests/multiVersion/targetedTestsLastLtsFeatures/accumulator_fix_last_lts.js
@@ -34,12 +34,14 @@ load('jstests/multiVersion/libs/multi_cluster.js'); // For upgradeCluster()
st.rs1.getSecondary().getDB(jsTestName())
];
// In the last-lts, we don't have the 'internalQueryForceClassicEngine' query knob.
if (isGreaterLastContinous) {
// Turns to the classic engine at the shards.
dbs.forEach(
(db) => assert.commandWorked(
- db.adminCommand({setParameter: 1, internalQueryForceClassicEngine: false}),
+ db.adminCommand(
+ {setParameter: 1, internalQueryEnableSlotBasedExecutionEngine: false}),
`at node ${db.getMongo().host}`));
}
@@ -47,13 +49,14 @@ load('jstests/multiVersion/libs/multi_cluster.js'); // For upgradeCluster()
const classicRes = coll.aggregate(pipeline).toArray();
verifyThis(classicRes);
// In the last-lts, we have neither the 'internalQueryForceClassicEngine' query knob
// nor the SBE $group pushdown feature.
if (isGreaterLastContinous) {
// Turns to the SBE engine at the shards.
dbs.forEach(
(db) => assert.commandWorked(
- db.adminCommand({setParameter: 1, internalQueryForceClassicEngine: true}),
+ db.adminCommand(
+ {setParameter: 1, internalQueryEnableSlotBasedExecutionEngine: true}),
`at node ${db.getMongo().host}`));
// Verifies that the SBE engine's results are same as the expected results.
@@ -34,12 +34,14 @@ load('jstests/multiVersion/libs/multi_cluster.js'); // For upgradeCluster()
st.rs1.getSecondary().getDB(jsTestName())
];
- // In the last-lts, we don't have the 'internalQueryForceClassicEngine' query knob.
+ // In the last-lts, we don't have the 'internalQueryEnableSlotBasedExecutionEngine'
+ // query knob.
if (isGreaterLastContinous) {
// Turns to the classic engine at the shards.
@@ -47,13 +49,14 @@ load('jstests/multiVersion/libs/multi_cluster.js'); // For upgradeCluster()
const classicRes = coll.aggregate(pipeline).toArray();
verifyThis(classicRes);
- // In the last-lts, we have neither the 'internalQueryForceClassicEngine' query knob
- // nor the SBE $group pushdown feature.
+ // In the last-lts, we have neither the 'internalQueryEnableSlotBasedExecutionEngine'
+ // query knob nor the SBE $group pushdown feature.
if (isGreaterLastContinous) {
// Turns to the SBE engine at the shards.